@@ -3,8 +3,6 @@ library(survey)
 library(vardpoor)
 library(IC2)
 
-test_check("convey")
-
-
+# test_check("convey")
 
 
